@@ -19,6 +19,16 @@ int check_translation(const char *tableList, const char *str,
 int check_translation_with_mode(const char *tableList, const char *str,
 				const char *typeform, const char *expected, int mode);
 
+/* Check if a string is backtranslated as expected. Return 0 if the
+   backtranslation is as expected and 1 otherwise. */
+int check_backtranslation(const char *tableList, const char *str,
+		      const char *typeform, const char *expected);
+
+/* Check if a string is backtranslated as expected. Return 0 if the
+   backtranslation is as expected and 1 otherwise. */
+int check_backtranslation_with_mode(const char *tableList, const char *str,
+				const char *typeform, const char *expected, int mode);
+
 /* Check if a string is hyphenated as expected. Return 0 if the
    hyphenation is as expected and 1 otherwise. */
 int check_hyphenation(const char *tableList, const char *str, const char *expected);
